@@ -29,8 +29,6 @@
 
 #include <QWidget>
 
-// KDE includes
-
 class QCheckBox;
 class QComboBox;
 class EquationEdit;
@@ -45,7 +43,7 @@ class KPrinterDlg : public QWidget
 	Q_OBJECT
 public:
 	/// Getting the common arguments.
-	KPrinterDlg( QWidget *parent = 0 );
+	explicit KPrinterDlg( QWidget *parent = 0 );
 
 	bool printHeaderTable();
 	void setPrintHeaderTable( bool status );
